Learn R Programming

resultant (version 1.0.0)

numberOfRealRoots: Number of real roots

Description

Number of distinct real roots of a univariate polynomial.

Usage

numberOfRealRoots(qspray)

Value

An integer, the number of real roots of the polynomial.

Arguments

qspray

a univariate qspray polynomial

Examples

Run this code
library(resultant)
x <- qlone(1)
P <- 2*x^4 + x^3 - 3*x^2 - x + 1
numberOfRealRoots(P)

Run the code above in your browser using DataLab