powered by
Principal Sturm-Habicht sequence of a polynomial with rational coefficients.
principalSturmHabicht(qspray, var = 1)
For a univariate polynomial, this returns a vector of bigq
bigq
rational numbers. For a multivariate polynomial, this returns a list of qspray
qspray
polynomials that do not involve the var-th variable.
var
a qspray polynomial with at most nine variables
integer indicating with respect to which variable the resultant is desired (e.g. 1 for x and 2 for y)
1
x
2
y
library(resultant) x <- qlone(1) y <- qlone(2) qspray <- x^3*y^2 - 5*x*y^2 + 7*x - 2 principalSturmHabicht(qspray, var = 1) principalSturmHabicht(qspray, var = 2)
Run the code above in your browser using DataLab