powered by
Number of distinct real roots of a univariate polynomial.
numberOfRealRoots(qspray)
An integer, the number of real roots of the polynomial.
a univariate qspray polynomial
qspray
library(resultant) x <- qlone(1) P <- 2*x^4 + x^3 - 3*x^2 - x + 1 numberOfRealRoots(P)
Run the code above in your browser using DataLab